@@ -33,6 +33,7 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
                                       const char *name,
                                       const char *realm,
                                       const char *flat_name,
+                                      const char *dns_name,
                                       const char *id,
                                       enum sss_domain_mpg_mode mpg_mode,
                                       bool enumerate,
@@ -101,6 +102,14 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
         }
     }
 
+    if (dns_name != NULL) {
+        dom->dns_name = talloc_strdup(dom, dns_name);
+        if (dom->dns_name == NULL) {
+            DEBUG(SSSDBG_OP_FAILURE, "Failed to copy dns name.\n");
+            goto fail;
+        }
+    }
+
     if (id != NULL) {
         dom->domain_id = talloc_strdup(dom, id);
         if (dom->domain_id == NULL) {
@@ -191,6 +200,9 @@ struct sss_domain_info *new_subdomain(TALLOC_CTX *mem_ctx,
     dom->override_gid = parent->override_gid;
 
     dom->gssapi_services = parent->gssapi_services;
+    dom->gssapi_indicators_map = parent->gssapi_indicators_map;
+
+    dom->not_found_counter = 0;
 
     if (parent->sysdb == NULL) {
         DEBUG(SSSDBG_OP_FAILURE, "Missing sysdb context in parent domain.\n");
@@ -273,6 +285,17 @@ check_subdom_config_file(struct confdb_ctx *confdb,
         goto done;
     }
 
+    /* allow to set pam_gssapi_indicators_map */
+    ret = confdb_get_string_as_list(confdb, subdomain, sd_conf_path,
+                                    CONFDB_PAM_GSSAPI_INDICATORS_MAP,
+                                    &subdomain->gssapi_indicators_map);
+    if (ret != EOK && ret != ENOENT) {
+        DEBUG(SSSDBG_OP_FAILURE,
+              "Failed to get %s option for the subdomain: %s\n",
+              CONFDB_PAM_GSSAPI_INDICATORS_MAP, subdomain->name);
+        goto done;
+    }
+
     /* case_sensitive=Preserving */
     ret = confdb_get_string(confdb, tmp_ctx, sd_conf_path,
                             CONFDB_DOMAIN_CASE_SENSITIVE, NULL,
@@ -386,6 +409,7 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
     const char *attrs[] = {"cn",
                            SYSDB_SUBDOMAIN_REALM,
                            SYSDB_SUBDOMAIN_FLAT,
+                           SYSDB_SUBDOMAIN_DNS,
                            SYSDB_SUBDOMAIN_ID,
                            SYSDB_SUBDOMAIN_MPG,
                            SYSDB_SUBDOMAIN_ENUM,
@@ -399,6 +423,7 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
     const char *name;
     const char *realm;
     const char *flat;
+    const char *dns;
     const char *id;
     const char *forest;
     const char *str_mpg_mode;
@@ -456,6 +481,9 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
         flat = ldb_msg_find_attr_as_string(res->msgs[i],
                                            SYSDB_SUBDOMAIN_FLAT, NULL);
 
+        dns = ldb_msg_find_attr_as_string(res->msgs[i],
+                                          SYSDB_SUBDOMAIN_DNS, NULL);
+
         id = ldb_msg_find_attr_as_string(res->msgs[i],
                                          SYSDB_SUBDOMAIN_ID, NULL);
 
@@ -523,11 +551,24 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
                         goto done;
                     }
                 }
+                if ((dom->dns_name == NULL && dns != NULL)
+                        || (dom->dns_name != NULL && dns != NULL
+                            && strcasecmp(dom->dns_name, dns) != 0)) {
+                    DEBUG(SSSDBG_TRACE_INTERNAL,
+                          "DNS name changed from [%s] to [%s]!\n",
+                           dom->dns_name, dns);
+                    talloc_zfree(dom->dns_name);
+                    dom->dns_name = talloc_strdup(dom, dns);
+                    if (dom->dns_name == NULL) {
+                        ret = ENOMEM;
+                        goto done;
+                    }
+                }
                 if ((dom->domain_id == NULL && id != NULL)
                         || (dom->domain_id != NULL && id != NULL
                             && strcasecmp(dom->domain_id, id) != 0)) {
                     DEBUG(SSSDBG_TRACE_INTERNAL,
-                          "Domain changed from [%s] to [%s]!\n",
+                          "Domain ID changed from [%s] to [%s]!\n",
                            dom->domain_id, id);
                     talloc_zfree(dom->domain_id);
                     dom->domain_id = talloc_strdup(dom, id);
@@ -612,7 +653,7 @@ errno_t sysdb_update_subdomains(struct sss_domain_info *domain,
         /* If not found in loop it is a new subdomain */
         if (dom == NULL) {
             dom = new_subdomain(domain, domain, name, realm,
-                                flat, id, mpg_mode, enumerate, forest,
+                                flat, dns, id, mpg_mode, enumerate, forest,
                                 upn_suffixes, trust_direction, confdb,
                                 enabled);
             if (dom == NULL) {
@@ -645,6 +686,7 @@ errno_t sysdb_master_domain_update(struct sss_domain_info *domain)
     const char *attrs[] = {"cn",
                            SYSDB_SUBDOMAIN_REALM,
                            SYSDB_SUBDOMAIN_FLAT,
+                           SYSDB_SUBDOMAIN_DNS,
                            SYSDB_SUBDOMAIN_ID,
                            SYSDB_SUBDOMAIN_FOREST,
                            SYSDB_UPN_SUFFIXES,
@@ -706,6 +748,19 @@ errno_t sysdb_master_domain_update(struct sss_domain_info *domain)
         }
     }
 
+    tmp_str = ldb_msg_find_attr_as_string(res->msgs[0], SYSDB_SUBDOMAIN_DNS,
+                                          NULL);
+    if (tmp_str != NULL &&
+        (domain->dns_name == NULL ||
+         strcasecmp(tmp_str, domain->dns_name) != 0)) {
+        talloc_free(domain->dns_name);
+        domain->dns_name = talloc_strdup(domain, tmp_str);
+        if (domain->dns_name == NULL) {
+            ret = ENOMEM;
+            goto done;
+        }
+    }
+
     tmp_str = ldb_msg_find_attr_as_string(res->msgs[0], SYSDB_SUBDOMAIN_ID,
                                           NULL);
     if (tmp_str != NULL &&
@@ -848,6 +903,7 @@ done:
 errno_t sysdb_master_domain_add_info(struct sss_domain_info *domain,
                                      const char *realm,
                                      const char *flat,
+                                     const char *dns,
                                      const char *id,
                                      const char *forest,
                                      struct ldb_message_element *upn_suffixes)
@@ -892,6 +948,24 @@ errno_t sysdb_master_domain_add_info(struct sss_domain_info *domain,
         do_update = true;
     }
 
+    if (dns != NULL && (domain->dns_name == NULL ||
+                         strcmp(domain->dns_name, dns) != 0)) {
+        ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_DNS,
+                                LDB_FLAG_MOD_REPLACE, NULL);
+        if (ret != LDB_SUCCESS) {
+            ret = sysdb_error_to_errno(ret);
+            goto done;
+        }
+
+        ret = ldb_msg_add_string(msg, SYSDB_SUBDOMAIN_DNS, dns);
+        if (ret != LDB_SUCCESS) {
+            ret = sysdb_error_to_errno(ret);
+            goto done;
+        }
+
+        do_update = true;
+    }
+
     if (id != NULL && (domain->domain_id == NULL ||
                        strcmp(domain->domain_id, id) != 0)) {
         ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_ID,
@@ -1004,7 +1078,8 @@ done:
 
 errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
                               const char *name, const char *realm,
-                              const char *flat_name, const char *domain_id,
+                              const char *flat_name, const char *dns_name,
+                              const char *domain_id,
                               enum sss_domain_mpg_mode mpg_mode,
                               bool enumerate, const char *forest,
                               uint32_t trust_direction,
@@ -1017,6 +1092,7 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
     const char *attrs[] = {"cn",
                            SYSDB_SUBDOMAIN_REALM,
                            SYSDB_SUBDOMAIN_FLAT,
+                           SYSDB_SUBDOMAIN_DNS,
                            SYSDB_SUBDOMAIN_ID,
                            SYSDB_SUBDOMAIN_MPG,
                            SYSDB_SUBDOMAIN_ENUM,
@@ -1030,6 +1106,7 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
     bool store = false;
     int realm_flags = 0;
     int flat_flags = 0;
+    int dns_flags = 0;
     int id_flags = 0;
     int mpg_flags = 0;
     int enum_flags = 0;
@@ -1064,6 +1141,7 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
         store = true;
         if (realm) realm_flags = LDB_FLAG_MOD_ADD;
         if (flat_name) flat_flags = LDB_FLAG_MOD_ADD;
+        if (dns_name) dns_flags = LDB_FLAG_MOD_ADD;
         if (domain_id) id_flags = LDB_FLAG_MOD_ADD;
         mpg_flags = LDB_FLAG_MOD_ADD;
         enum_flags = LDB_FLAG_MOD_ADD;
@@ -1088,6 +1166,13 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
                 flat_flags = LDB_FLAG_MOD_REPLACE;
             }
         }
+        if (dns_name) {
+            tmp_str = ldb_msg_find_attr_as_string(res->msgs[0],
+                                                  SYSDB_SUBDOMAIN_DNS, NULL);
+            if (!tmp_str || strcasecmp(tmp_str, dns_name) != 0) {
+                dns_flags = LDB_FLAG_MOD_REPLACE;
+            }
+        }
         if (domain_id) {
             tmp_str = ldb_msg_find_attr_as_string(res->msgs[0],
                                                   SYSDB_SUBDOMAIN_ID, NULL);
@@ -1116,6 +1201,11 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
                 mpg_flags = LDB_FLAG_MOD_REPLACE;
             }
             break;
+        case MPG_DEFAULT:
+            if (strcasecmp(tmp_str, "default") != 0) {
+                mpg_flags = LDB_FLAG_MOD_REPLACE;
+            }
+            break;
         }
 
         tmp_bool = ldb_msg_find_attr_as_bool(res->msgs[0], SYSDB_SUBDOMAIN_ENUM,
@@ -1150,7 +1240,8 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
         }
     }
 
-    if (!store && realm_flags == 0 && flat_flags == 0 && id_flags == 0
+    if (!store && realm_flags == 0 && flat_flags == 0
+            && dns_flags == 0 && id_flags == 0
             && mpg_flags == 0 && enum_flags == 0 && forest_flags == 0
             && td_flags == 0 && upn_flags == 0) {
         ret = EOK;
@@ -1206,6 +1297,20 @@ errno_t sysdb_subdomain_store(struct sysdb_ctx *sysdb,
         }
     }
 
+    if (dns_flags) {
+        ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_DNS, dns_flags, NULL);
+        if (ret != LDB_SUCCESS) {
+            ret = sysdb_error_to_errno(ret);
+            goto done;
+        }
+
+        ret = ldb_msg_add_string(msg, SYSDB_SUBDOMAIN_DNS, dns_name);
+        if (ret != LDB_SUCCESS) {
+            ret = sysdb_error_to_errno(ret);
+            goto done;
+        }
+    }
+
     if (id_flags) {
         ret = ldb_msg_add_empty(msg, SYSDB_SUBDOMAIN_ID, id_flags, NULL);
         if (ret != LDB_SUCCESS) {
@@ -1380,6 +1485,67 @@ errno_t sysdb_subdomain_content_delete(struct sysdb_ctx *sysdb,
     return sysdb_subdomain_delete_with_filter(sysdb, name, filter);
 }
 
+errno_t
+sysdb_subdomain_get_id_by_name(TALLOC_CTX *mem_ctx,
+                               struct sysdb_ctx *sysdb,
+                               const char *name,
+                               const char **_id)
+{
+    TALLOC_CTX *tmp_ctx;
+    struct ldb_dn *base_dn;
+    const char *attrs[] = {SYSDB_DOMAIN_ID, NULL};
+    struct ldb_message **msgs;
+    const char *id;
+    char *filter;
+    size_t count;
+    errno_t ret;
+
+    tmp_ctx = talloc_new(NULL);
+    if (tmp_ctx == NULL) {
+        return ENOMEM;
+    }
+
+    base_dn = sysdb_base_dn(sysdb, tmp_ctx);
+    if (base_dn == NULL) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    filter = talloc_asprintf(tmp_ctx,
+        "(&(" SYSDB_OBJECTCLASS "=" SYSDB_SUBDOMAIN_CLASS ")(cn=%s))", name);
+    if (filter == NULL) {
+        ret = ENOMEM;
+        goto done;
+    }
+
+    ret = sysdb_search_entry(tmp_ctx, sysdb, base_dn, LDB_SCOPE_ONELEVEL,
+                             filter, attrs, &count, &msgs);
+    if (ret != EOK) {
+        goto done;
+    }
+
+    if (count != 1) {
+        ret = ERR_MULTIPLE_ENTRIES;
+        goto done;
+    }
+
+    id = ldb_msg_find_attr_as_string(msgs[0], SYSDB_DOMAIN_ID, NULL);
+    if (id == NULL) {
+        ret = ENOENT;
+        goto done;
+    }
+
+    *_id = talloc_steal(mem_ctx, id);
+
+    ret = EOK;
+
+done:
+    talloc_free(tmp_ctx);
+
+    return ret;
+}
+
+
 errno_t
 sysdb_domain_get_domain_resolution_order(TALLOC_CTX *mem_ctx,
                                          struct sysdb_ctx *sysdb,
@@ -1446,6 +1612,7 @@ done:
     return ret;
 }
 
+
 errno_t
 sysdb_get_site(TALLOC_CTX *mem_ctx,
                struct sss_domain_info *dom,
