@@ -384,7 +384,7 @@ ad_create_2way_trust_options(TALLOC_CTX *mem_ctx,
 
     ret = ad_set_sdap_options(ad_options, ad_options->id);
     if (ret != EOK) {
-        DEBUG(SSSDBG_CRIT_FAILURE, "ad_set_sdap_options failed");
+        DEBUG(SSSDBG_CRIT_FAILURE, "ad_set_sdap_options failed\n");
         talloc_free(ad_options);
         return NULL;
     }
@@ -978,10 +978,11 @@ ad_resolve_callback(void *private_data, struct fo_server *server)
     TALLOC_CTX *tmp_ctx;
     struct ad_service *service;
     struct resolv_hostent *srvaddr;
-    struct sockaddr_storage *sockaddr;
+    struct sockaddr *sockaddr;
     char *address;
     char *new_uri;
     int new_port;
+    socklen_t sockaddr_len;
     const char *srv_name;
     struct ad_server_data *sdata = NULL;
 
@@ -1036,7 +1037,8 @@ ad_resolve_callback(void *private_data, struct fo_server *server)
     }
     DEBUG(SSSDBG_CONF_SETTINGS, "Constructed uri '%s'\n", new_uri);
 
-    sockaddr = resolv_get_sockaddr_address(tmp_ctx, srvaddr, service->port);
+    sockaddr = resolv_get_sockaddr_address(tmp_ctx, srvaddr, service->port,
+                    &sockaddr_len);
     if (sockaddr == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "resolv_get_sockaddr_address failed.\n");
         ret = EIO;
@@ -1051,6 +1053,7 @@ ad_resolve_callback(void *private_data, struct fo_server *server)
         service->sdap->uri = new_uri;
         talloc_zfree(service->sdap->sockaddr);
         service->sdap->sockaddr = talloc_steal(service->sdap, sockaddr);
+	service->sdap->sockaddr_len = sockaddr_len;
     }
 
     talloc_zfree(service->gc->uri);
@@ -1068,7 +1071,9 @@ ad_resolve_callback(void *private_data, struct fo_server *server)
 
         service->gc->sockaddr = resolv_get_sockaddr_address(service->gc,
                                                             srvaddr,
-                                                            new_port);
+                                                            new_port,
+                                                            &sockaddr_len);
+        service->gc->sockaddr_len = sockaddr_len;
     } else {
         /* Make sure there always is an URI even if we know that this
          * server doesn't support GC. That way the lookup would go through
@@ -1076,7 +1081,8 @@ ad_resolve_callback(void *private_data, struct fo_server *server)
          */
         service->gc->uri = talloc_strdup(service->gc, service->sdap->uri);
         service->gc->sockaddr = talloc_memdup(service->gc, service->sdap->sockaddr,
-                                              sizeof(struct sockaddr_storage));
+                                              service->sdap->sockaddr_len);
+        service->gc->sockaddr_len = service->sdap->sockaddr_len;
     }
 
     if (!service->gc->uri) {
@@ -1311,6 +1317,7 @@ ad_set_search_bases(struct sdap_options *id_opts,
     size_t o;
     struct sdap_domain *sdap_dom;
     bool has_default;
+    struct ldb_context *ldb;
     const int search_base_options[] = { SDAP_USER_SEARCH_BASE,
                                         SDAP_GROUP_SEARCH_BASE,
                                         SDAP_NETGROUP_SEARCH_BASE,
@@ -1328,6 +1335,7 @@ ad_set_search_bases(struct sdap_options *id_opts,
         /* If no specific sdom was given, use the first in the list. */
         sdap_dom = id_opts->sdom;
     }
+    ldb = sysdb_ctx_get_ldb(sdap_dom->dom->sysdb);
 
     has_default = sdap_dom->search_bases != NULL;
 
@@ -1361,31 +1369,31 @@ ad_set_search_bases(struct sdap_options *id_opts,
     }
 
     /* Default search */
-    ret = sdap_parse_search_base(id_opts, id_opts->basic,
+    ret = sdap_parse_search_base(id_opts, ldb, id_opts->basic,
                                  SDAP_SEARCH_BASE,
                                  &sdap_dom->search_bases);
     if (ret != EOK && ret != ENOENT) goto done;
 
     /* User search */
-    ret = sdap_parse_search_base(id_opts, id_opts->basic,
+    ret = sdap_parse_search_base(id_opts, ldb, id_opts->basic,
                                  SDAP_USER_SEARCH_BASE,
                                  &sdap_dom->user_search_bases);
     if (ret != EOK && ret != ENOENT) goto done;
 
     /* Group search base */
-    ret = sdap_parse_search_base(id_opts, id_opts->basic,
+    ret = sdap_parse_search_base(id_opts, ldb, id_opts->basic,
                                  SDAP_GROUP_SEARCH_BASE,
                                  &sdap_dom->group_search_bases);
     if (ret != EOK && ret != ENOENT) goto done;
 
     /* Netgroup search */
-    ret = sdap_parse_search_base(id_opts, id_opts->basic,
+    ret = sdap_parse_search_base(id_opts, ldb, id_opts->basic,
                                  SDAP_NETGROUP_SEARCH_BASE,
                                  &sdap_dom->netgroup_search_bases);
     if (ret != EOK && ret != ENOENT) goto done;
 
     /* Service search */
-    ret = sdap_parse_search_base(id_opts, id_opts->basic,
+    ret = sdap_parse_search_base(id_opts, ldb, id_opts->basic,
                                  SDAP_SERVICE_SEARCH_BASE,
                                  &sdap_dom->service_search_bases);
     if (ret != EOK && ret != ENOENT) goto done;
