@@ -46,6 +46,10 @@ extern struct sdap_attr_map ad_autofs_mobject_map[];
 
 extern struct sdap_attr_map ad_autofs_entry_map[];
 
+extern struct sdap_attr_map ad_iphost_map[];
+
+extern struct sdap_attr_map ad_ipnetwork_map[];
+
 extern struct dp_option ad_dyndns_opts[];
 
 extern struct sdap_attr_map ad_sudorule_map[];
