@@ -661,7 +661,7 @@ build_filter(TALLOC_CTX *mem_ctx,
     hash_key_t *keys;
     unsigned long int count;
     unsigned long int i;
-    char *filter;
+    char *filter = NULL;
     char *rdn_val;
     const char *rdn_attr;
     char *safe_rdn;
@@ -1082,7 +1082,7 @@ combine_cmdgroups(TALLOC_CTX *mem_ctx,
         }
 
         ret = add_strings_lists(mem_ctx, values, cmdgroup->expanded,
-                                false, discard_const(&values));
+                                false, &values);
         if (ret != EOK) {
             talloc_free(tmp_ctx);
             return NULL;
