@@ -264,7 +264,7 @@ struct tevent_req *users_get_send(TALLOC_CTX *memctx,
              * in the search filter.
              */
             uid = strtouint32(filter_value, &endptr, 10);
-            if (errno != EOK) {
+            if ((errno != EOK) || *endptr || (filter_value == endptr)) {
                 ret = EINVAL;
                 goto done;
             }
@@ -534,7 +534,7 @@ static void users_get_done(struct tevent_req *subreq)
     struct users_get_state *state = tevent_req_data(req,
                                                      struct users_get_state);
     char *endptr;
-    uid_t uid;
+    uid_t uid = 0;
     int dp_error = DP_ERR_FATAL;
     int ret;
 
@@ -742,7 +742,7 @@ struct tevent_req *groups_get_send(TALLOC_CTX *memctx,
              * in the search filter.
              */
             gid = strtouint32(filter_value, &endptr, 10);
-            if (errno != EOK) {
+            if ((errno != EOK) || *endptr || (filter_value == endptr)) {
                 ret = EINVAL;
                 goto done;
             }
@@ -1449,6 +1449,24 @@ sdap_handle_acct_req_send(TALLOC_CTX *mem_ctx,
                                      noexist_delete);
         break;
 
+    case BE_REQ_SUBID_RANGES:
+#ifdef BUILD_SUBID
+        if (!ar->extra_value) {
+            ret = ERR_GET_ACCT_SUBID_RANGES_NOT_SUPPORTED;
+            state->err = "This id_provider doesn't support subid ranges";
+            goto done;
+        }
+        subreq = subid_ranges_get_send(state, be_ctx->ev, id_ctx,
+                                       sdom, conn,
+                                       ar->filter_value,
+                                       ar->extra_value);
+#else
+        ret = ERR_GET_ACCT_SUBID_RANGES_NOT_SUPPORTED;
+        state->err = "Subid ranges are not supported";
+        goto done;
+#endif
+        break;
+
     case BE_REQ_NETGROUP:
         if (ar->filter_type != BE_FILTER_NAME) {
             ret = EINVAL;
@@ -1533,6 +1551,11 @@ sdap_handle_acct_req_send(TALLOC_CTX *mem_ctx,
     default: /*fail*/
         ret = EINVAL;
         state->err = "Invalid request type";
+        DEBUG(SSSDBG_OP_FAILURE,
+              "Unexpected request type: 0x%X [%s:%s] in %s\n",
+              ar->entry_type, ar->filter_value,
+              ar->extra_value?ar->extra_value:"-",
+              ar->domain);
         goto done;
     }
 
@@ -1578,6 +1601,14 @@ sdap_handle_acct_req_done(struct tevent_req *subreq)
         err = "Init group lookup failed";
         ret = groups_by_user_recv(subreq, &state->dp_error, &state->sdap_ret);
         break;
+    case BE_REQ_SUBID_RANGES:
+        err = "Subid ranges lookup failed";
+#ifdef BUILD_SUBID
+        ret = subid_ranges_get_recv(subreq, &state->dp_error, &state->sdap_ret);
+#else
+        ret = EINVAL;
+#endif
+        break;
     case BE_REQ_NETGROUP:
         err = "Netgroup lookup failed";
         ret = ldap_netgroup_get_recv(subreq, &state->dp_error, &state->sdap_ret);
