@@ -22,6 +22,7 @@
 #ifndef _SDAP_H_
 #define _SDAP_H_
 
+#include <ldb.h>
 #include "providers/backend.h"
 #include <ldap.h>
 #include "util/sss_ldap.h"
@@ -89,7 +90,8 @@ struct sdap_service {
     char *name;
     char *uri;
     char *kinit_service_name;
-    struct sockaddr_storage *sockaddr;
+    struct sockaddr *sockaddr;
+    socklen_t sockaddr_len;
 };
 
 struct sdap_ppolicy_data {
@@ -288,6 +290,7 @@ enum sdap_user_attrs {
     SDAP_AT_USER_AUTH_TYPE,
     SDAP_AT_USER_CERT,
     SDAP_AT_USER_EMAIL,
+    SDAP_AT_USER_PASSKEY,
 
     SDAP_OPTS_USER /* attrs counter */
 };
@@ -419,12 +422,15 @@ struct sdap_attr_map {
 
 struct sdap_search_base {
     const char *basedn;
+    struct ldb_context *ldb;
+    struct ldb_dn *ldb_basedn;
     int scope;
     const char *filter;
 };
 
 errno_t
 sdap_create_search_base(TALLOC_CTX *mem_ctx,
+                        struct ldb_context *ldb,
                         const char *unparsed_base,
                         int scope,
                         const char *filter,
@@ -458,6 +464,7 @@ struct sdap_domain {
     struct sdap_search_base **iphost_search_bases;
     struct sdap_search_base **ipnetwork_search_bases;
     struct sdap_search_base **autofs_search_bases;
+    struct sdap_search_base **ignore_user_search_bases;
 #ifdef BUILD_SUBID
     struct sdap_search_base **subid_ranges_search_bases;
 #endif
