@@ -1182,7 +1182,6 @@ struct sdap_process_group_state {
     struct ldb_message_element* ghost_dns;
     const char **attrs;
     const char *filter;
-    size_t count;
     size_t check_count;
 
     bool enumeration;
@@ -1351,8 +1350,7 @@ done:
 
 static int
 sdap_process_missing_member_2307bis(struct tevent_req *req,
-                                    char *user_dn,
-                                    unsigned num_users)
+                                    char *user_dn)
 {
     struct sdap_process_group_state *grp_state =
         tevent_req_data(req, struct sdap_process_group_state);
@@ -1432,8 +1430,7 @@ sdap_process_group_members_2307bis(struct tevent_req *req,
                 DEBUG(SSSDBG_TRACE_LIBS,
                       "Searching LDAP for missing user entry\n");
                 ret = sdap_process_missing_member_2307bis(req,
-                                                          member_dn,
-                                                          memberel->num_values);
+                                                          member_dn);
                 if (ret != EOK) {
                     DEBUG(SSSDBG_CRIT_FAILURE,
                           "Error processing missing member #%d (%s):\n",
@@ -1460,7 +1457,6 @@ sdap_process_group_members_2307bis(struct tevent_req *req,
         memberel->values = talloc_steal(state->group, state->sysdb_dns->values);
         memberel->num_values = state->sysdb_dns->num_values;
     } else {
-        state->count = state->check_count;
         ret = EBUSY;
     }
 
@@ -1695,7 +1691,6 @@ next:
         DEBUG(SSSDBG_TRACE_FUNC,
               "Error reading group member[%d]: %s. Skipping\n",
                ret, strerror(ret));
-        state->count--;
     }
 
     if (state->check_count == 0) {
