@@ -23,10 +23,12 @@
 #include <sys/time.h>
 #include <time.h>
 #include "util/util.h"
+#include "util/sss_chain_id.h"
 #include "responder/common/responder_packet.h"
 #include "responder/common/responder.h"
 #include "providers/data_provider.h"
 
+#ifdef BUILD_FILES_PROVIDER
 static errno_t
 sss_dp_account_files_params(struct sss_domain_info *dom,
                             enum sss_dp_acct_type type_in,
@@ -83,6 +85,7 @@ sss_dp_account_files_params(struct sss_domain_info *dom,
     DEBUG(SSSDBG_CRIT_FAILURE, "Unhandled type %d\n", type_in);
     return EINVAL;
 }
+#endif
 
 static errno_t
 sss_dp_get_account_filter(TALLOC_CTX *mem_ctx,
@@ -213,33 +216,15 @@ sss_dp_get_account_send(TALLOC_CTX *mem_ctx,
         goto done;
     }
 
-    if (NEED_CHECK_PROVIDER(dom->provider) == false) {
-        if (strcmp(dom->provider, "files") == 0) {
-            /* This is a special case. If the files provider is just being updated,
-             * we issue an enumeration request. We always use the same request type
-             * (user enumeration) to make sure concurrent requests are just chained
-             * in the Data Provider */
-            ret = sss_dp_account_files_params(dom, type, opt_name,
-                                              &type, &opt_name);
-            if (ret == EOK) {
-                state->dp_error = DP_ERR_OK;
-                state->error = EOK;
-                state->error_message = talloc_strdup(state, "Success");
-                if (state->error_message == NULL) {
-                    ret = ENOMEM;
-                    goto done;
-                }
-                goto done;
-            } else if (ret != EAGAIN) {
-                DEBUG((ret == ENOENT) ? SSSDBG_MINOR_FAILURE : SSSDBG_OP_FAILURE,
-                      "Failed to set files provider update [%d]: %s\n",
-                      ret, sss_strerror(ret));
-                goto done;
-            }
-            /* EAGAIN, fall through to issuing the request */
-        } else {
-            DEBUG(SSSDBG_TRACE_INTERNAL, "Domain %s does not check DP\n",
-                  dom->name);
+#ifdef BUILD_FILES_PROVIDER
+    if (is_files_provider(dom)) {
+        /* This is a special case. If the files provider is just being updated,
+         * we issue an enumeration request. We always use the same request type
+         * (user enumeration) to make sure concurrent requests are just chained
+         * in the Data Provider */
+        ret = sss_dp_account_files_params(dom, type, opt_name,
+                                          &type, &opt_name);
+        if (ret == EOK) {
             state->dp_error = DP_ERR_OK;
             state->error = EOK;
             state->error_message = talloc_strdup(state, "Success");
@@ -247,10 +232,16 @@ sss_dp_get_account_send(TALLOC_CTX *mem_ctx,
                 ret = ENOMEM;
                 goto done;
             }
-            ret = EOK;
+            goto done;
+        } else if (ret != EAGAIN) {
+            DEBUG((ret == ENOENT) ? SSSDBG_MINOR_FAILURE : SSSDBG_OP_FAILURE,
+                  "Failed to set files provider update [%d]: %s\n",
+                  ret, sss_strerror(ret));
             goto done;
         }
+        /* EAGAIN, fall through to issuing the request */
     }
+#endif
 
     ret = sss_dp_get_domain_conn(rctx, dom->conn_name, &be_conn);
     if (ret != EOK) {
@@ -276,7 +267,7 @@ sss_dp_get_account_send(TALLOC_CTX *mem_ctx,
     subreq = sbus_call_dp_dp_getAccountInfo_send(state, be_conn->conn,
                  be_conn->bus_name, SSS_BUS_PATH, dp_flags,
                  entry_type, filter, dom->name, extra,
-                 rctx->client_id_num);
+                 sss_chain_id_get());
     if (subreq == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to create subrequest!\n");
         ret = ENOMEM;
@@ -406,7 +397,7 @@ sss_dp_resolver_get_send(TALLOC_CTX *mem_ctx,
                                                   SSS_BUS_PATH,
                                                   dp_flags, entry_type,
                                                   filter_type, filter_value,
-                                                  rctx->client_id_num);
+                                                  sss_chain_id_get());
     if (subreq == NULL) {
         DEBUG(SSSDBG_CRIT_FAILURE, "Unable to create subrequest!\n");
         ret = ENOMEM;
@@ -418,10 +409,7 @@ sss_dp_resolver_get_send(TALLOC_CTX *mem_ctx,
     ret = EAGAIN;
 
 done:
-    if (ret == EOK) {
-        tevent_req_done(req);
-        tevent_req_post(req, rctx->ev);
-    } else if (ret != EAGAIN) {
+    if (ret != EAGAIN) {
         tevent_req_error(req, ret);
         tevent_req_post(req, rctx->ev);
     }
