@@ -45,7 +45,8 @@
 #define FIRST_LETTER "s"
 #define UID      1234
 #define DOMAIN   "sssddomain"
-#define ORIGINAL_HOME "/home/user"
+#define ORIGINAL_HOME "/home/USER"
+#define LOWERCASE_HOME "/home/user"
 #define FLATNAME "flatname"
 #define HOMEDIR_SUBSTR "/mnt/home"
 
@@ -915,12 +916,11 @@ struct name_init_test_ctx {
 };
 
 #define GLOBAL_FULL_NAME_FORMAT "%1$s@%2$s"
-#define GLOBAL_RE_EXPRESSION "(?P<name>[^@]+)@?(?P<domain>[^@]*$)"
-
-#define TEST_DOMAIN_NAME "test.dom"
+#define TEST_DOMAIN_NAME_LDAP "test.dom"
+#define TEST_DOMAIN_NAME_IPA "test.ipa"
+#define TEST_DOMAIN_NAMES TEST_DOMAIN_NAME_LDAP "," TEST_DOMAIN_NAME_IPA
 #define DOMAIN_FULL_NAME_FORMAT "%3$s\\%1$s"
-#define DOMAIN_RE_EXPRESSION "(((?P<domain>[^\\\\]+)\\\\(?P<name>.+$))|" \
-                             "((?P<name>[^@]+)@(?P<domain>.+$))|" \
+#define DOMAIN_RE_EXPRESSION "(((?P<name>[^@]+)@(?P<domain>.+$))|" \
                              "(^(?P<name>[^@\\\\]+)$))"
 
 static int confdb_test_setup(void **state)
@@ -945,7 +945,7 @@ static int confdb_test_setup(void **state)
 
     talloc_free(conf_db);
 
-    val[0] = TEST_DOMAIN_NAME;
+    val[0] = TEST_DOMAIN_NAMES;
     ret = confdb_add_param(test_ctx->confdb, true,
                            "config/sssd", "domains", val);
     assert_int_equal(ret, EOK);
@@ -955,12 +955,12 @@ static int confdb_test_setup(void **state)
                            "config/sssd", "full_name_format", val);
     assert_int_equal(ret, EOK);
 
-    val[0] = GLOBAL_RE_EXPRESSION;
+    val[0] = SSS_DEFAULT_RE;
     ret = confdb_add_param(test_ctx->confdb, true,
                            "config/sssd", "re_expression", val);
     assert_int_equal(ret, EOK);
 
-    dompath = talloc_asprintf(test_ctx, "config/domain/%s", TEST_DOMAIN_NAME);
+    dompath = talloc_asprintf(test_ctx, "config/domain/%s", TEST_DOMAIN_NAME_LDAP);
     assert_non_null(dompath);
 
     val[0] = "ldap";
@@ -980,6 +980,26 @@ static int confdb_test_setup(void **state)
 
     talloc_free(dompath);
 
+    dompath = talloc_asprintf(test_ctx, "config/domain/%s", TEST_DOMAIN_NAME_IPA);
+    assert_non_null(dompath);
+
+    val[0] = "ipa";
+    ret = confdb_add_param(test_ctx->confdb, true,
+                           dompath, "id_provider", val);
+    assert_int_equal(ret, EOK);
+
+    val[0] = DOMAIN_FULL_NAME_FORMAT;
+    ret = confdb_add_param(test_ctx->confdb, true,
+                           dompath, "full_name_format", val);
+    assert_int_equal(ret, EOK);
+
+    val[0] = SSS_IPA_AD_DEFAULT_RE;
+    ret = confdb_add_param(test_ctx->confdb, true,
+                           dompath, "re_expression", val);
+    assert_int_equal(ret, EOK);
+
+    talloc_free(dompath);
+
     check_leaks_push(test_ctx);
     *state = test_ctx;
     return 0;
@@ -1008,12 +1028,12 @@ void test_sss_names_init(void **state)
     ret = sss_names_init(test_ctx, test_ctx->confdb, NULL, &names_ctx);
     assert_int_equal(ret, EOK);
     assert_non_null(names_ctx);
-    assert_string_equal(names_ctx->re_pattern, GLOBAL_RE_EXPRESSION);
+    assert_string_equal(names_ctx->re_pattern, SSS_DEFAULT_RE);
     assert_string_equal(names_ctx->fq_fmt, GLOBAL_FULL_NAME_FORMAT);
 
     talloc_free(names_ctx);
 
-    ret = sss_names_init(test_ctx, test_ctx->confdb, TEST_DOMAIN_NAME,
+    ret = sss_names_init(test_ctx, test_ctx->confdb, TEST_DOMAIN_NAME_LDAP,
                          &names_ctx);
     assert_int_equal(ret, EOK);
     assert_non_null(names_ctx);
@@ -1023,6 +1043,52 @@ void test_sss_names_init(void **state)
     talloc_free(names_ctx);
 }
 
+void test_sss_names_ipa_ad_regexp(void **state)
+{
+    struct name_init_test_ctx *test_ctx;
+    struct sss_names_ctx *names_ctx;
+    char *name;
+    char *domain;
+    int ret;
+
+    test_ctx = talloc_get_type(*state, struct name_init_test_ctx);
+
+    ret = sss_names_init(test_ctx, test_ctx->confdb, TEST_DOMAIN_NAME_IPA,
+                         &names_ctx);
+    assert_int_equal(ret, EOK);
+    assert_non_null(names_ctx);
+    assert_non_null(names_ctx->re_pattern);
+
+    ret = sss_parse_name(names_ctx, names_ctx, "user@domain", &domain, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(name, "user");
+    assert_string_equal(domain, "domain");
+    talloc_free(name);
+    talloc_free(domain);
+
+    ret = sss_parse_name(names_ctx, names_ctx, "mail@group@domain", &domain, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(name, "mail@group");
+    assert_string_equal(domain, "domain");
+    talloc_free(name);
+    talloc_free(domain);
+
+    ret = sss_parse_name(names_ctx, names_ctx, "domain\\user", &domain, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(name, "user");
+    assert_string_equal(domain, "domain");
+    talloc_free(name);
+    talloc_free(domain);
+
+    ret = sss_parse_name(names_ctx, names_ctx, "user", &domain, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(name, "user");
+    assert_null(domain);
+    talloc_free(name);
+
+    talloc_free(names_ctx);
+}
+
 void test_well_known_sid_to_name(void **state)
 {
     int ret;
@@ -1055,12 +1121,65 @@ void test_well_known_sid_to_name(void **state)
     ret = well_known_sid_to_name("S-1-0-0-", &dom, &name);
     assert_int_equal(ret, EINVAL);
 
+    ret = well_known_sid_to_name("S-1-3", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-3-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-3-4", &dom, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(dom, "CREATOR AUTHORITY");
+    assert_string_equal(name, "OWNER RIGHTS");
+
+    ret = well_known_sid_to_name("S-1-16", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-16-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-16-8192", &dom, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(dom, "MANDATORY LABEL AUTHORITY");
+    assert_string_equal(name, "MEDIUM");
+
+    ret = well_known_sid_to_name("S-1-18", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-18-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-18-1", &dom, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(dom, "AUTHENTICATION AUTHORITY");
+    assert_string_equal(name, "AUTHENTICATION ASSERTION");
+
     ret = well_known_sid_to_name("S-1-5", &dom, &name);
     assert_int_equal(ret, EINVAL);
 
     ret = well_known_sid_to_name("S-1-5-", &dom, &name);
     assert_int_equal(ret, EINVAL);
 
+    ret = well_known_sid_to_name("S-1-5-5", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-5-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-5-7", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-5-7-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-5-7-8-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-5-7-8", &dom, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(dom, "NT AUTHORITY");
+    assert_string_equal(name, "LOGON ID");
+
     ret = well_known_sid_to_name("S-1-5-6", &dom, &name);
     assert_int_equal(ret, EOK);
     assert_string_equal(dom, "NT AUTHORITY");
@@ -1092,6 +1211,33 @@ void test_well_known_sid_to_name(void **state)
     ret = well_known_sid_to_name("S-1-5-32-551-", &dom, &name);
     assert_int_equal(ret, EINVAL);
 
+    ret = well_known_sid_to_name("S-1-5-64", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-64-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-64-10", &dom, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(dom, "NT AUTHORITY");
+    assert_string_equal(name, "NTLM AUTHENTICATION");
+
+    ret = well_known_sid_to_name("S-1-5-64-10-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-65", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-65-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
+
+    ret = well_known_sid_to_name("S-1-5-65-1", &dom, &name);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(dom, "NT AUTHORITY");
+    assert_string_equal(name, "THIS ORGANIZATION CERTIFICATE");
+
+    ret = well_known_sid_to_name("S-1-5-65-1-", &dom, &name);
+    assert_int_equal(ret, EINVAL);
 }
 
 void test_name_to_well_known_sid(void **state)
@@ -1128,6 +1274,26 @@ void test_name_to_well_known_sid(void **state)
     ret = name_to_well_known_sid("NT AUTHORITY", "DIALUP", &sid);
     assert_int_equal(ret, EOK);
     assert_string_equal(sid, "S-1-5-1");
+
+    ret = name_to_well_known_sid("NT AUTHORITY", "NTLM AUTHENTICATION", &sid);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(sid, "S-1-5-64-10");
+
+    ret = name_to_well_known_sid("NT AUTHORITY", "THIS ORGANIZATION CERTIFICATE", &sid);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(sid, "S-1-5-65-1");
+
+    ret = name_to_well_known_sid("NT AUTHORITY", "LOGON ID", &sid);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(sid, "S-1-5-5-0-0");
+
+    ret = name_to_well_known_sid("MANDATORY LABEL AUTHORITY", "MEDIUM", &sid);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(sid, "S-1-16-8192");
+
+    ret = name_to_well_known_sid("AUTHENTICATION AUTHORITY", "KEY_TRUST_IDENTITY", &sid);
+    assert_int_equal(ret, EOK);
+    assert_string_equal(sid, "S-1-18-4");
 }
 
 #define TEST_SANITIZE_INPUT "TestUser@Test.Domain"
@@ -1316,6 +1482,12 @@ void test_expand_homedir_template(void **state)
     check_expanded_value(tmp_ctx, homedir_ctx, DUMMY"%o"DUMMY2,
                                                DUMMY ORIGINAL_HOME DUMMY2);
 
+    check_expanded_value(tmp_ctx, homedir_ctx, "%h", LOWERCASE_HOME);
+    check_expanded_value(tmp_ctx, homedir_ctx, DUMMY"%h", DUMMY LOWERCASE_HOME);
+    check_expanded_value(tmp_ctx, homedir_ctx, "%h"DUMMY, LOWERCASE_HOME DUMMY);
+    check_expanded_value(tmp_ctx, homedir_ctx, DUMMY"%h"DUMMY2,
+                                               DUMMY LOWERCASE_HOME DUMMY2);
+
     check_expanded_value(tmp_ctx, homedir_ctx, "%F", FLATNAME);
     check_expanded_value(tmp_ctx, homedir_ctx, DUMMY"%F", DUMMY FLATNAME);
     check_expanded_value(tmp_ctx, homedir_ctx, "%F"DUMMY, FLATNAME DUMMY);
@@ -1364,11 +1536,14 @@ static int teardown_leak_tests(void **state)
     return 0;
 }
 
+/* add_strings_list() is an alias for add_strings_list_ex() that allows for
+ * duplicate values.
+ */
 void test_add_strings_lists(void **state)
 {
-    const char *l1[] = {"a", "b", "c", NULL};
-    const char *l2[] = {"1", "2", "3", NULL};
-    char **res;
+    const char *l1[] = {"a", "b", "c", "b", NULL};
+    const char *l2[] = {"1", "2", "3", "2", NULL};
+    const char **res;
     int ret;
     size_t c;
     size_t d;
@@ -1459,6 +1634,113 @@ void test_add_strings_lists(void **state)
     talloc_free(res);
 }
 
+/* add_strings_list_ex(skip_dups=false) was tested by add_string_list().
+ * We now test add_strings_list_ex(skip_dups=true).
+ */
+void test_add_strings_lists_ex(void **state)
+{
+    /* Set duplicate values at the end of the array to simplify the comparison */
+    const char *l1[] = {"a", "b", "c", "b", NULL};
+    const char *l2[] = {"1", "2", "3", "2", NULL};
+    const char *r1[sizeof(l1) / sizeof(*l1) - 1];
+    const char *r2[sizeof(l2) / sizeof(*l2) - 1];
+    const char **res;
+    int ret;
+    size_t c;
+    size_t d;
+
+    /* The expected results must have the same pointers */
+    memcpy(r1, l1, sizeof(r1) - sizeof(*r1));
+    r1[sizeof(r1) / sizeof(*r1) - 1] = NULL;
+    memcpy(r2, l2, sizeof(r2) - sizeof(*r2));
+    r2[sizeof(r2) / sizeof(*r2) - 1] = NULL;
+
+    ret = add_strings_lists_ex(global_talloc_context, NULL, NULL, true, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    assert_null(res[0]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, NULL, NULL, false, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    assert_null(res[0]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, l1, NULL, false, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    for (c = 0; r1[c] != NULL; c++) {
+        /* 'copy_strings' is 'false', pointers must be equal */
+        assert_int_equal(memcmp(&r1[c], &res[c], sizeof(char *)), 0);
+    }
+    assert_null(res[c]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, l1, NULL, true, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    for (c = 0; r1[c] != NULL; c++) {
+        /* 'copy_strings' is 'true', pointers must be different, but strings
+         * must be equal */
+        assert_int_not_equal(memcmp(&r1[c], &res[c], sizeof(char *)), 0);
+        assert_string_equal(r1[c], res[c]);
+    }
+    assert_null(res[c]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, NULL, l1, false, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    for (c = 0; r1[c] != NULL; c++) {
+        /* 'copy_strings' is 'false', pointers must be equal */
+        assert_int_equal(memcmp(&r1[c], &res[c], sizeof(char *)), 0);
+    }
+    assert_null(res[c]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, NULL, l1, true, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    for (c = 0; r1[c] != NULL; c++) {
+        /* 'copy_strings' is 'true', pointers must be different, but strings
+         * must be equal */
+        assert_int_not_equal(memcmp(&r1[c], &res[c], sizeof(char *)), 0);
+        assert_string_equal(r1[c], res[c]);
+    }
+    assert_null(res[c]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, l1, l2, false, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    for (c = 0; r1[c] != NULL; c++) {
+        /* 'copy_strings' is 'false', pointers must be equal */
+        assert_int_equal(memcmp(&r1[c], &res[c], sizeof(char *)), 0);
+    }
+    for (d = 0; r2[d] != NULL; d++) {
+        assert_int_equal(memcmp(&r2[d], &res[c+d], sizeof(char *)), 0);
+    }
+    assert_null(res[c+d]);
+    talloc_free(res);
+
+    ret = add_strings_lists_ex(global_talloc_context, l1, l2, true, true, &res);
+    assert_int_equal(ret, EOK);
+    assert_non_null(res);
+    for (c = 0; r1[c] != NULL; c++) {
+        /* 'copy_strings' is 'true', pointers must be different, but strings
+         * must be equal */
+        assert_int_not_equal(memcmp(&r1[c], &res[c], sizeof(char *)), 0);
+        assert_string_equal(r1[c], res[c]);
+    }
+    for (d = 0; r2[d] != NULL; d++) {
+        assert_int_not_equal(memcmp(&r2[d], &res[c+d], sizeof(char *)), 0);
+        assert_string_equal(r2[d], res[c+d]);
+    }
+    assert_null(res[c+d]);
+    talloc_free(res);
+}
+
 void test_sss_write_krb5_conf_snippet(void **state)
 {
     int ret;
@@ -1575,7 +1857,6 @@ static int unique_file_test_teardown(void **state)
 static void assert_destructor(TALLOC_CTX *owner,
                               struct unique_file_test_ctx *test_ctx)
 {
-    int fd;
     errno_t ret;
     char *check_filename;
 
@@ -1589,10 +1870,8 @@ static void assert_destructor(TALLOC_CTX *owner,
 
     talloc_free(owner);
 
-    ret = check_and_open_readonly(test_ctx->filename, &fd,
-                                  geteuid(), getegid(),
-                                  (S_IRUSR | S_IWUSR | S_IFREG), 0);
-    close(fd);
+    ret = check_file(check_filename, geteuid(), getegid(),
+                     (S_IRUSR | S_IWUSR | S_IFREG), 0, NULL, true);
     assert_int_not_equal(ret, EOK);
 }
 
@@ -1601,7 +1880,6 @@ static void sss_unique_file_test(struct unique_file_test_ctx *test_ctx,
 {
     int fd;
     errno_t ret;
-    struct stat sb;
     TALLOC_CTX *owner = NULL;
 
     if (test_destructor) {
@@ -1613,8 +1891,8 @@ static void sss_unique_file_test(struct unique_file_test_ctx *test_ctx,
     assert_int_not_equal(fd, -1);
     assert_int_equal(ret, EOK);
 
-    ret = check_fd(fd, geteuid(), getegid(),
-                   (S_IRUSR | S_IWUSR | S_IFREG), 0, &sb);
+    ret = check_file(test_ctx->filename, geteuid(), getegid(),
+                     (S_IRUSR | S_IWUSR | S_IFREG), 0, NULL, false);
     close(fd);
     assert_int_equal(ret, EOK);
 
@@ -1648,7 +1926,6 @@ static void test_sss_unique_file_neg(void **state)
 static void sss_unique_filename_test(struct unique_file_test_ctx *test_ctx,
                                      bool test_destructor)
 {
-    int fd;
     errno_t ret;
     char *tmp_filename;
     TALLOC_CTX *owner = NULL;
@@ -1669,10 +1946,8 @@ static void sss_unique_filename_test(struct unique_file_test_ctx *test_ctx,
                              strlen(tmp_filename) - sizeof("XXXXXX")),
                      0);
 
-    ret = check_and_open_readonly(test_ctx->filename, &fd,
-                                  geteuid(), getegid(),
-                                  (S_IRUSR | S_IWUSR | S_IFREG), 0);
-    close(fd);
+    ret = check_file(test_ctx->filename, geteuid(), getegid(),
+                     (S_IRUSR | S_IWUSR | S_IFREG), 0, NULL, true);
     assert_int_equal(ret, EOK);
 
     assert_destructor(owner, test_ctx);
@@ -1706,7 +1981,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_true(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context, "wedfkwefjk", &cv_opts);
@@ -1716,7 +1991,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_true(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context, "no_ocsp", &cv_opts);
@@ -1726,7 +2001,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_false(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context, "no_verification",
@@ -1737,7 +2012,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_true(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context,
@@ -1748,7 +2023,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_false(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context,
@@ -1770,7 +2045,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_true(cv_opts->do_ocsp);
     assert_string_equal(cv_opts->ocsp_default_responder, "abc");
     assert_string_equal(cv_opts->ocsp_default_responder_signing_cert, "def");
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context, "crl_file=hij",
@@ -1781,7 +2056,20 @@ static void test_parse_cert_verify_opts(void **state)
     assert_true(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_string_equal(cv_opts->crl_file, "hij");
+    assert_string_equal(cv_opts->crl_files[0], "hij");
+    talloc_free(cv_opts);
+
+    ret = parse_cert_verify_opts(global_talloc_context,
+                                 "crl_file=file1.pem,crl_file=file2.pem",
+                                 &cv_opts);
+    assert_int_equal(ret, EOK);
+    assert_true(cv_opts->do_verification);
+    assert_false(cv_opts->verification_partial_chain);
+    assert_true(cv_opts->do_ocsp);
+    assert_null(cv_opts->ocsp_default_responder);
+    assert_null(cv_opts->ocsp_default_responder_signing_cert);
+    assert_string_equal(cv_opts->crl_files[0], "file1.pem");
+    assert_string_equal(cv_opts->crl_files[1], "file2.pem");
     talloc_free(cv_opts);
 
     ret = parse_cert_verify_opts(global_talloc_context, "partial_chain", &cv_opts);
@@ -1791,7 +2079,7 @@ static void test_parse_cert_verify_opts(void **state)
     assert_true(cv_opts->do_ocsp);
     assert_null(cv_opts->ocsp_default_responder);
     assert_null(cv_opts->ocsp_default_responder_signing_cert);
-    assert_null(cv_opts->crl_file);
+    assert_null(cv_opts->crl_files);
     talloc_free(cv_opts);
 }
 
@@ -1962,6 +2250,8 @@ static void test_sss_get_domain_mappings_content(void **state)
     assert_int_equal(ret, EOK);
     assert_string_equal(content,
                         "[domain_realm]\n"
+                        ".configured.dom = CONFIGURED.DOM\n"
+                        "configured.dom = CONFIGURED.DOM\n"
                         ".subdom1.dom = SUBDOM1.DOM\n"
                         "subdom1.dom = SUBDOM1.DOM\n"
                         ".subdom2.dom = SUBDOM2.DOM\n"
@@ -1987,6 +2277,8 @@ static void test_sss_get_domain_mappings_content(void **state)
     assert_int_equal(ret, EOK);
     assert_string_equal(content,
                         "[domain_realm]\n"
+                        ".configured.dom = CONFIGURED.DOM\n"
+                        "configured.dom = CONFIGURED.DOM\n"
                         ".subdom1.dom = SUBDOM1.DOM\n"
                         "subdom1.dom = SUBDOM1.DOM\n"
                         ".subdom2.dom = SUBDOM2.DOM\n"
@@ -2114,6 +2406,9 @@ int main(int argc, const char *argv[])
         cmocka_unit_test_setup_teardown(test_sss_names_init,
                                         confdb_test_setup,
                                         confdb_test_teardown),
+        cmocka_unit_test_setup_teardown(test_sss_names_ipa_ad_regexp,
+                                        confdb_test_setup,
+                                        confdb_test_teardown),
 
         cmocka_unit_test_setup_teardown(test_get_next_domain,
                                         setup_dom_tree, teardown_dom_tree),
@@ -2146,6 +2441,9 @@ int main(int argc, const char *argv[])
         cmocka_unit_test_setup_teardown(test_add_strings_lists,
                                         setup_leak_tests,
                                         teardown_leak_tests),
+        cmocka_unit_test_setup_teardown(test_add_strings_lists_ex,
+                                        setup_leak_tests,
+                                        teardown_leak_tests),
         cmocka_unit_test(test_sss_write_krb5_conf_snippet),
         cmocka_unit_test(test_get_hidden_path),
         cmocka_unit_test_setup_teardown(test_sss_unique_file,
