@@ -34,9 +34,12 @@ from sssd_nss import NssReturnCode
 from sssd_passwd import (call_sssd_getpwnam,
                          call_sssd_getpwuid)
 from sssd_group import call_sssd_getgrnam, call_sssd_getgrgid
-from files_ops import passwd_ops_setup, group_ops_setup, PasswdOps, GroupOps
+from files_ops import PasswdOps, GroupOps
 from util import unindent
 
+def have_files_provider():
+    return os.environ['FILES_PROVIDER'] == "enabled"
+
 # Sync this with files_ops.c
 FILES_REALLOC_CHUNK = 64
 
@@ -291,12 +294,6 @@ def disabled_files_domain(request):
     return None
 
 
-@pytest.fixture
-def no_sssd_conf(request):
-    create_sssd_fixture(request)
-    return None
-
-
 @pytest.fixture
 def domain_resolution_order(request):
     conf = unindent("""\
@@ -539,6 +536,8 @@ def assert_group_overriden():
 
 
 # User tests
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getpwnam_after_start(add_user_with_canary, files_domain_only):
     """
     Test that after startup without any additional operations, a user
@@ -549,6 +548,8 @@ def test_getpwnam_after_start(add_user_with_canary, files_domain_only):
     assert user == USER1
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getpwuid_after_start(add_user_with_canary, files_domain_only):
     """
     Test that after startup without any additional operations, a user
@@ -559,6 +560,8 @@ def test_getpwuid_after_start(add_user_with_canary, files_domain_only):
     assert user == USER1
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_user_overriden(add_user_with_canary, files_domain_only):
     """
     Test that user override works with files domain only
@@ -577,6 +580,8 @@ def test_user_overriden(add_user_with_canary, files_domain_only):
     assert_user_overriden()
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_group_overriden(add_group_with_canary, files_domain_only):
     """
     Test that user override works with files domain only
@@ -591,6 +596,8 @@ def test_group_overriden(add_group_with_canary, files_domain_only):
     assert_group_overriden()
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getpwnam_neg(files_domain_only):
     """
     Test that a nonexistent user cannot be resolved by name
@@ -599,6 +606,8 @@ def test_getpwnam_neg(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getpwuid_neg(files_domain_only):
     """
     Test that a nonexistent user cannot be resolved by UID
@@ -607,6 +616,8 @@ def test_getpwuid_neg(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_root_does_not_resolve(files_domain_only):
     """
     SSSD currently does not resolve the root user even though it can
@@ -619,6 +630,8 @@ def test_root_does_not_resolve(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_uid_zero_does_not_resolve(files_domain_only):
     """
     SSSD currently does not resolve the UID 0 even though it can
@@ -631,6 +644,8 @@ def test_uid_zero_does_not_resolve(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_add_remove_add_file_user(setup_pw_with_canary, files_domain_only):
     """
     Test that removing a user is detected and the user
@@ -653,6 +668,8 @@ def test_add_remove_add_file_user(setup_pw_with_canary, files_domain_only):
     check_user(USER1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_mod_user_shell(add_user_with_canary, files_domain_only):
     """
     Test that modifying a user shell is detected and the user
@@ -680,6 +697,8 @@ def incomplete_user_setup(pwd_ops, del_field, exp_field):
     return exp_user
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_user_no_shell(setup_pw_with_canary, files_domain_only):
     """
     Test that resolving a user without a shell defined works and returns
@@ -688,6 +707,8 @@ def test_user_no_shell(setup_pw_with_canary, files_domain_only):
     check_user(incomplete_user_setup(setup_pw_with_canary, 'shell', ''))
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_user_no_dir(setup_pw_with_canary, files_domain_only):
     """
     Test that resolving a user without a homedir defined works and returns
@@ -696,6 +717,8 @@ def test_user_no_dir(setup_pw_with_canary, files_domain_only):
     check_user(incomplete_user_setup(setup_pw_with_canary, 'dir', ''))
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_user_no_gecos(setup_pw_with_canary, files_domain_only):
     """
     Test that resolving a user without a gecos defined works and returns
@@ -704,6 +727,8 @@ def test_user_no_gecos(setup_pw_with_canary, files_domain_only):
     check_user(incomplete_user_setup(setup_pw_with_canary, 'gecos', ''))
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_user_no_passwd(setup_pw_with_canary, files_domain_only):
     """
     Test that resolving a user without a password defined works and returns
@@ -719,6 +744,8 @@ def bad_incomplete_user_setup(pwd_ops, del_field):
     pwd_ops.useradd(**adduser)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_incomplete_user_fail(setup_pw_with_canary, files_domain_only):
     """
     Test resolving an incomplete user where the missing field is required
@@ -732,6 +759,8 @@ def test_incomplete_user_fail(setup_pw_with_canary, files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_after_start(add_group_with_canary, files_domain_only):
     """
     Test that after startup without any additional operations, a group
@@ -740,6 +769,8 @@ def test_getgrnam_after_start(add_group_with_canary, files_domain_only):
     check_group(GROUP1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrgid_after_start(add_group_with_canary, files_domain_only):
     """
     Test that after startup without any additional operations, a group
@@ -748,6 +779,8 @@ def test_getgrgid_after_start(add_group_with_canary, files_domain_only):
     check_group_by_gid(GROUP1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_neg(files_domain_only):
     """
     Test that a nonexistent group cannot be resolved
@@ -756,6 +789,8 @@ def test_getgrnam_neg(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrgid_neg(files_domain_only):
     """
     Test that a nonexistent group cannot be resolved
@@ -764,6 +799,8 @@ def test_getgrgid_neg(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_root_group_does_not_resolve(files_domain_only):
     """
     SSSD currently does not resolve the root group even though it can
@@ -776,6 +813,8 @@ def test_root_group_does_not_resolve(files_domain_only):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_gid_zero_does_not_resolve(files_domain_only):
     """
     SSSD currently does not resolve the group with GID 0 even though it
@@ -789,6 +828,8 @@ def test_gid_zero_does_not_resolve(files_domain_only):
 
 
 @pytest.mark.flaky(max_runs=5)
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_add_remove_add_file_group(
         setup_pw_with_canary, setup_gr_with_canary, files_domain_only
 ):
@@ -814,6 +855,8 @@ def test_add_remove_add_file_group(
     check_group(GROUP1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_mod_group_name(add_group_with_canary, files_domain_only):
     """
     Test that modifying a group name is detected and the group
@@ -828,6 +871,8 @@ def test_mod_group_name(add_group_with_canary, files_domain_only):
     check_group(modgroup)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_mod_group_gid(add_group_with_canary, files_domain_only):
     """
     Test that modifying a group name is detected and the group
@@ -849,6 +894,8 @@ def add_group_nomem_with_canary(passwd_ops_setup, group_ops_setup):
     )
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_no_members(add_group_nomem_with_canary, files_domain_only):
     """
     Test that after startup without any additional operations, a group
@@ -893,6 +940,8 @@ def members_check(added_groups):
             assert group['name'] in groups
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_members_users_first(setup_pw_with_canary,
                                       setup_gr_with_canary,
                                       files_domain_only):
@@ -907,6 +956,8 @@ def test_getgrnam_members_users_first(setup_pw_with_canary,
     members_check([GROUP1])
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_members_users_multiple(setup_pw_with_canary,
                                          setup_gr_with_canary,
                                          files_domain_only):
@@ -921,6 +972,8 @@ def test_getgrnam_members_users_multiple(setup_pw_with_canary,
     members_check([GROUP12])
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_members_groups_first(setup_pw_with_canary,
                                        setup_gr_with_canary,
                                        files_domain_only):
@@ -935,6 +988,8 @@ def test_getgrnam_members_groups_first(setup_pw_with_canary,
     members_check([GROUP1])
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_ghost(setup_pw_with_canary,
                         setup_gr_with_canary,
                         files_domain_only):
@@ -981,6 +1036,8 @@ def ghost_and_member_test(pw_ops, grp_ops, reverse):
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_user_ghost_and_member(setup_pw_with_canary,
                                         setup_gr_with_canary,
                                         files_domain_only):
@@ -992,6 +1049,8 @@ def test_getgrnam_user_ghost_and_member(setup_pw_with_canary,
                           False)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_user_member_and_ghost(setup_pw_with_canary,
                                         setup_gr_with_canary,
                                         files_domain_only):
@@ -1004,6 +1063,8 @@ def test_getgrnam_user_member_and_ghost(setup_pw_with_canary,
                           True)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_add_remove_members(setup_pw_with_canary,
                                      add_group_nomem_with_canary,
                                      files_domain_only):
@@ -1048,6 +1109,8 @@ def test_getgrnam_add_remove_members(setup_pw_with_canary,
     assert 'group_nomem' in groups
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_getgrnam_add_remove_ghosts(setup_pw_with_canary,
                                     add_group_nomem_with_canary,
                                     files_domain_only):
@@ -1086,6 +1149,8 @@ def realloc_users(pwd_ops, num):
     check_user(user)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_realloc_users_exact(setup_pw_with_canary, files_domain_only):
     """
     Test that returning exactly FILES_REALLOC_CHUNK users (see files_ops.c)
@@ -1095,6 +1160,8 @@ def test_realloc_users_exact(setup_pw_with_canary, files_domain_only):
     realloc_users(setup_pw_with_canary, FILES_REALLOC_CHUNK)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_realloc_users(setup_pw_with_canary, files_domain_only):
     """
     Test that returning exactly FILES_REALLOC_CHUNK users (see files_ops.c)
@@ -1113,6 +1180,8 @@ def realloc_groups(grp_ops, num):
 
 
 @pytest.mark.flaky(max_runs=5)
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_realloc_groups_exact(setup_gr_with_canary, files_domain_only):
     """
     Test that returning exactly FILES_REALLOC_CHUNK groups (see files_ops.c)
@@ -1123,6 +1192,8 @@ def test_realloc_groups_exact(setup_gr_with_canary, files_domain_only):
 
 
 @pytest.mark.flaky(max_runs=5)
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_realloc_groups(setup_gr_with_canary, files_domain_only):
     """
     Test that returning exactly FILES_REALLOC_CHUNK groups (see files_ops.c)
@@ -1133,6 +1204,8 @@ def test_realloc_groups(setup_gr_with_canary, files_domain_only):
 
 
 # Files domain autoconfiguration tests
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_no_sssd_domain(add_user_with_canary, no_sssd_domain):
     """
     Test that if no sssd domain is configured, sssd will add the implicit one
@@ -1142,6 +1215,8 @@ def test_no_sssd_domain(add_user_with_canary, no_sssd_domain):
     assert user == USER1
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_proxy_to_files_domain_only(add_user_with_canary,
                                     proxy_to_files_domain_only):
     """
@@ -1151,6 +1226,8 @@ def test_proxy_to_files_domain_only(add_user_with_canary,
     assert res == NssReturnCode.NOTFOUND
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_no_files_domain(add_user_with_canary, no_files_domain):
     """
     Test that if no files domain is configured, sssd will add the implicit one
@@ -1160,6 +1237,8 @@ def test_no_files_domain(add_user_with_canary, no_files_domain):
     assert user == USER1
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_disable_files_domain(add_user_with_canary, disabled_files_domain):
     """
     Test disabled files domain
@@ -1169,16 +1248,8 @@ def test_disable_files_domain(add_user_with_canary, disabled_files_domain):
     assert res != NssReturnCode.SUCCESS
 
 
-def test_no_sssd_conf(add_user_with_canary, no_sssd_conf):
-    """
-    Test that running without sssd.conf implicitly configures one with
-    id_provider=files
-    """
-    res, user = sssd_getpwnam_sync(USER1["name"])
-    assert res == NssReturnCode.SUCCESS
-    assert user == USER1
-
-
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_multiple_passwd_group_files(add_user_with_canary,
                                      add_group_with_canary,
                                      files_multiple_sources):
@@ -1196,6 +1267,8 @@ def test_multiple_passwd_group_files(add_user_with_canary,
     check_group(ALT_GROUP1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_multiple_files_created_after_startup(add_user_with_canary,
                                               add_group_with_canary,
                                               files_multiple_sources_nocreate):
@@ -1222,6 +1295,8 @@ def test_multiple_files_created_after_startup(add_user_with_canary,
     check_group(ALT_GROUP1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_files_with_domain_resolution_order(add_user_with_canary,
                                             domain_resolution_order):
     """
@@ -1231,6 +1306,8 @@ def test_files_with_domain_resolution_order(add_user_with_canary,
     check_user(USER1)
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_files_with_default_domain_suffix(add_user_with_canary,
                                           default_domain_suffix):
     """
@@ -1246,6 +1323,8 @@ def test_files_with_default_domain_suffix(add_user_with_canary,
     assert found_user == USER1
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_files_with_override_homedir(add_user_with_canary,
                                      override_homedir_and_shell):
     res, user = sssd_getpwnam_sync(USER1["name"])
@@ -1253,6 +1332,8 @@ def test_files_with_override_homedir(add_user_with_canary,
     assert user["dir"] == USER1["dir"]
 
 
+@pytest.mark.skipif(not have_files_provider(),
+                    reason="'files provider' disabled, skipping")
 def test_files_with_override_shell(add_user_with_canary,
                                    override_homedir_and_shell):
     res, user = sssd_getpwnam_sync(USER1["name"])
