@@ -75,30 +75,30 @@ static void get_allow_all_rule(TALLOC_CTX *mem_ctx,
      * remote hosts.
      */
     rule = talloc_zero(mem_ctx, struct hbac_rule);
-    fail_if (rule == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rule == NULL, "Failed to allocate memory");
 
     rule->enabled = true;
 
     rule->services = talloc_zero(rule, struct hbac_rule_element);
-    fail_if (rule->services == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rule->services == NULL, "Failed to allocate memory");
     rule->services->category = HBAC_CATEGORY_ALL;
     rule->services->names = NULL;
     rule->services->groups = NULL;
 
     rule->users = talloc_zero(rule, struct hbac_rule_element);
-    fail_if (rule->users == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rule->users == NULL, "Failed to allocate memory");
     rule->users->category = HBAC_CATEGORY_ALL;
     rule->users->names = NULL;
     rule->users->groups = NULL;
 
     rule->targethosts = talloc_zero(rule, struct hbac_rule_element);
-    fail_if (rule->targethosts == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rule->targethosts == NULL, "Failed to allocate memory");
     rule->targethosts->category = HBAC_CATEGORY_ALL;
     rule->targethosts->names = NULL;
     rule->targethosts->groups = NULL;
 
     rule->srchosts = talloc_zero(rule, struct hbac_rule_element);
-    fail_if (rule->srchosts == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rule->srchosts == NULL, "Failed to allocate memory");
     rule->srchosts->category = HBAC_CATEGORY_ALL;
     rule->srchosts->names = NULL;
     rule->srchosts->groups = NULL;
@@ -112,19 +112,19 @@ static void get_test_user(TALLOC_CTX *mem_ctx,
     struct hbac_request_element *new_user;
 
     new_user = talloc_zero(mem_ctx, struct hbac_request_element);
-    fail_if (new_user == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_user == NULL, "Failed to allocate memory");
 
     new_user->name = talloc_strdup(new_user, HBAC_TEST_USER);
-    fail_if(new_user->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_user->name == NULL, "Failed to allocate memory");
 
     new_user->groups = talloc_array(new_user, const char *, 3);
-    fail_if(new_user->groups == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_user->groups == NULL, "Failed to allocate memory");
 
     new_user->groups[0] = talloc_strdup(new_user->groups, HBAC_TEST_GROUP1);
-    fail_if(new_user->groups[0] == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_user->groups[0] == NULL, "Failed to allocate memory");
 
     new_user->groups[1] = talloc_strdup(new_user->groups, HBAC_TEST_GROUP2);
-    fail_if(new_user->groups[1] == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_user->groups[1] == NULL, "Failed to allocate memory");
 
     new_user->groups[2] = NULL;
 
@@ -137,19 +137,19 @@ static void get_test_service(TALLOC_CTX *mem_ctx,
     struct hbac_request_element *new_service;
 
     new_service = talloc_zero(mem_ctx, struct hbac_request_element);
-    fail_if (new_service == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_service == NULL, "Failed to allocate memory");
 
     new_service->name = talloc_strdup(new_service, HBAC_TEST_SERVICE);
-    fail_if(new_service->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_service->name == NULL, "Failed to allocate memory");
 
     new_service->groups = talloc_array(new_service, const char *, 3);
-    fail_if(new_service->groups == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_service->groups == NULL, "Failed to allocate memory");
 
     new_service->groups[0] = talloc_strdup(new_service->groups, HBAC_TEST_SERVICEGROUP1);
-    fail_if(new_service->groups[0] == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_service->groups[0] == NULL, "Failed to allocate memory");
 
     new_service->groups[1] = talloc_strdup(new_service->groups, HBAC_TEST_SERVICEGROUP2);
-    fail_if(new_service->groups[1] == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_service->groups[1] == NULL, "Failed to allocate memory");
 
     new_service->groups[2] = NULL;
 
@@ -162,21 +162,21 @@ static void get_test_srchost(TALLOC_CTX *mem_ctx,
     struct hbac_request_element *new_srchost;
 
     new_srchost = talloc_zero(mem_ctx, struct hbac_request_element);
-    fail_if (new_srchost == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_srchost == NULL, "Failed to allocate memory");
 
     new_srchost->name = talloc_strdup(new_srchost, HBAC_TEST_SRCHOST);
-    fail_if(new_srchost->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_srchost->name == NULL, "Failed to allocate memory");
 
     new_srchost->groups = talloc_array(new_srchost, const char *, 3);
-    fail_if(new_srchost->groups == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_srchost->groups == NULL, "Failed to allocate memory");
 
     new_srchost->groups[0] = talloc_strdup(new_srchost->groups,
                                            HBAC_TEST_SRCHOSTGROUP1);
-    fail_if(new_srchost->groups[0] == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_srchost->groups[0] == NULL, "Failed to allocate memory");
 
     new_srchost->groups[1] = talloc_strdup(new_srchost->groups,
                                            HBAC_TEST_SRCHOSTGROUP2);
-    fail_if(new_srchost->groups[1] == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(new_srchost->groups[1] == NULL, "Failed to allocate memory");
 
     new_srchost->groups[2] = NULL;
 
@@ -197,7 +197,7 @@ START_TEST(ipa_hbac_test_allow_all)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -205,22 +205,22 @@ START_TEST(ipa_hbac_test_allow_all)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
     rules[0]->name = talloc_strdup(rules[0], "Allow All");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[1] = NULL;
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -246,7 +246,7 @@ START_TEST(ipa_hbac_test_allow_user)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -254,17 +254,17 @@ START_TEST(ipa_hbac_test_allow_user)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     /* Modify the rule to allow only a specific user */
     rules[0]->name = talloc_strdup(rules[0], "Allow user");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->users->category = HBAC_CATEGORY_NULL;
 
     rules[0]->users->names = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->users->names == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->users->names == NULL, "Failed to allocate memory");
 
     rules[0]->users->names[0] = HBAC_TEST_USER;
     rules[0]->users->names[1] = NULL;
@@ -273,13 +273,13 @@ START_TEST(ipa_hbac_test_allow_user)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -293,13 +293,13 @@ START_TEST(ipa_hbac_test_allow_user)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -326,7 +326,7 @@ START_TEST(ipa_hbac_test_allow_utf8)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -339,17 +339,17 @@ START_TEST(ipa_hbac_test_allow_utf8)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     rules[0]->name = talloc_strdup(rules[0], "Allow user");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->users->category = HBAC_CATEGORY_NULL;
 
     /* Modify the rule to allow only a specific user */
     rules[0]->users->names = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->users->names == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->users->names == NULL, "Failed to allocate memory");
 
     rules[0]->users->names[0] = (const char *) &user_utf8_upcase;
     rules[0]->users->names[1] = NULL;
@@ -358,7 +358,7 @@ START_TEST(ipa_hbac_test_allow_utf8)
     rules[0]->services->category = HBAC_CATEGORY_NULL;
 
     rules[0]->services->names = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->services->names == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->services->names == NULL, "Failed to allocate memory");
 
     rules[0]->services->names[0] = (const char *) &service_utf8_upcase;
     rules[0]->services->names[1] = NULL;
@@ -367,7 +367,7 @@ START_TEST(ipa_hbac_test_allow_utf8)
     rules[0]->srchosts->category = HBAC_CATEGORY_NULL;
 
     rules[0]->srchosts->names = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->services->names == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->services->names == NULL, "Failed to allocate memory");
 
     rules[0]->srchosts->names[0] = (const char *) &srchost_utf8_upcase;
     rules[0]->srchosts->names[1] = NULL;
@@ -376,13 +376,13 @@ START_TEST(ipa_hbac_test_allow_utf8)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -397,7 +397,7 @@ START_TEST(ipa_hbac_test_allow_utf8)
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -413,13 +413,13 @@ START_TEST(ipa_hbac_test_allow_utf8)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -446,7 +446,7 @@ START_TEST(ipa_hbac_test_allow_group)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -454,18 +454,18 @@ START_TEST(ipa_hbac_test_allow_group)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     /* Modify the rule to allow only a group of users */
     rules[0]->name = talloc_strdup(rules[0], "Allow group");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->users->category = HBAC_CATEGORY_NULL;
 
     rules[0]->users->names = NULL;
     rules[0]->users->groups = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->users->groups == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->users->groups == NULL, "Failed to allocate memory");
 
     rules[0]->users->groups[0] = HBAC_TEST_GROUP1;
     rules[0]->users->groups[1] = NULL;
@@ -474,13 +474,13 @@ START_TEST(ipa_hbac_test_allow_group)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -494,13 +494,13 @@ START_TEST(ipa_hbac_test_allow_group)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -527,7 +527,7 @@ START_TEST(ipa_hbac_test_allow_svc)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -535,17 +535,17 @@ START_TEST(ipa_hbac_test_allow_svc)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     /* Modify the rule to allow only a specific service */
     rules[0]->name = talloc_strdup(rules[0], "Allow service");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->services->category = HBAC_CATEGORY_NULL;
 
     rules[0]->services->names = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->services->names == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->services->names == NULL, "Failed to allocate memory");
 
     rules[0]->services->names[0] = HBAC_TEST_SERVICE;
     rules[0]->services->names[1] = NULL;
@@ -554,13 +554,13 @@ START_TEST(ipa_hbac_test_allow_svc)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -574,13 +574,13 @@ START_TEST(ipa_hbac_test_allow_svc)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -607,7 +607,7 @@ START_TEST(ipa_hbac_test_allow_svcgroup)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -615,18 +615,18 @@ START_TEST(ipa_hbac_test_allow_svcgroup)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     /* Modify the rule to allow only a group of users */
     rules[0]->name = talloc_strdup(rules[0], "Allow servicegroup");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->services->category = HBAC_CATEGORY_NULL;
 
     rules[0]->services->names = NULL;
     rules[0]->services->groups = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->services->groups == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->services->groups == NULL, "Failed to allocate memory");
 
     rules[0]->services->groups[0] = HBAC_TEST_SERVICEGROUP1;
     rules[0]->services->groups[1] = NULL;
@@ -635,13 +635,13 @@ START_TEST(ipa_hbac_test_allow_svcgroup)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -655,13 +655,13 @@ START_TEST(ipa_hbac_test_allow_svcgroup)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -688,7 +688,7 @@ START_TEST(ipa_hbac_test_allow_srchost)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -696,17 +696,17 @@ START_TEST(ipa_hbac_test_allow_srchost)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     /* Modify the rule to allow only a specific service */
     rules[0]->name = talloc_strdup(rules[0], "Allow srchost");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->srchosts->category = HBAC_CATEGORY_NULL;
 
     rules[0]->srchosts->names = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->srchosts->names == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->srchosts->names == NULL, "Failed to allocate memory");
 
     rules[0]->srchosts->names[0] = HBAC_TEST_SRCHOST;
     rules[0]->srchosts->names[1] = NULL;
@@ -715,13 +715,13 @@ START_TEST(ipa_hbac_test_allow_srchost)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -735,13 +735,13 @@ START_TEST(ipa_hbac_test_allow_srchost)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -768,7 +768,7 @@ START_TEST(ipa_hbac_test_allow_srchostgroup)
 
     /* Create a request */
     eval_req = talloc_zero(test_ctx, struct hbac_eval_req);
-    fail_if (eval_req == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(eval_req == NULL, "Failed to allocate memory");
 
     get_test_user(eval_req, &eval_req->user);
     get_test_service(eval_req, &eval_req->service);
@@ -776,18 +776,18 @@ START_TEST(ipa_hbac_test_allow_srchostgroup)
 
     /* Create the rules to evaluate against */
     rules = talloc_array(test_ctx, struct hbac_rule *, 2);
-    fail_if (rules == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules == NULL, "Failed to allocate memory");
 
     get_allow_all_rule(rules, &rules[0]);
 
     /* Modify the rule to allow only a group of users */
     rules[0]->name = talloc_strdup(rules[0], "Allow srchostgroup");
-    fail_if(rules[0]->name == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->name == NULL, "Failed to allocate memory");
     rules[0]->srchosts->category = HBAC_CATEGORY_NULL;
 
     rules[0]->srchosts->names = NULL;
     rules[0]->srchosts->groups = talloc_array(rules[0], const char *, 2);
-    fail_if(rules[0]->srchosts->groups == NULL, "Failed to allocate memory");
+    sss_ck_fail_if_msg(rules[0]->srchosts->groups == NULL, "Failed to allocate memory");
 
     rules[0]->srchosts->groups[0] = HBAC_TEST_SRCHOSTGROUP1;
     rules[0]->srchosts->groups[1] = NULL;
@@ -796,13 +796,13 @@ START_TEST(ipa_hbac_test_allow_srchostgroup)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_ALLOW,
+    ck_assert_msg(result == HBAC_EVAL_ALLOW,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_ALLOW),
@@ -816,13 +816,13 @@ START_TEST(ipa_hbac_test_allow_srchostgroup)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rules[0], &missing_attrs);
-    fail_unless(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs == 0,
+    ck_assert_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs == 0,
                 "Unexpected missing attributes. Got: %"PRIx32, missing_attrs);
 
     /* Evaluate the rules */
     result = hbac_evaluate(rules, eval_req, &info);
-    fail_unless(result == HBAC_EVAL_DENY,
+    ck_assert_msg(result == HBAC_EVAL_DENY,
                 "Expected [%s], got [%s]; "
                 "Error: [%s]",
                 hbac_result_string(HBAC_EVAL_DENY),
@@ -848,14 +848,14 @@ START_TEST(ipa_hbac_test_incomplete)
 
     /* Validate this rule */
     is_valid = hbac_rule_is_complete(rule, &missing_attrs);
-    fail_if(is_valid, "hbac_rule_is_complete failed");
-    fail_unless(missing_attrs | HBAC_RULE_ELEMENT_USERS,
+    sss_ck_fail_if_msg(is_valid, "hbac_rule_is_complete failed");
+    ck_assert_msg(missing_attrs | HBAC_RULE_ELEMENT_USERS,
                 "missing_attrs failed for HBAC_RULE_ELEMENT_USERS");
-    fail_unless(missing_attrs | HBAC_RULE_ELEMENT_SERVICES,
+    ck_assert_msg(missing_attrs | HBAC_RULE_ELEMENT_SERVICES,
                 "missing_attrs failed for HBAC_RULE_ELEMENT_SERVICES");
-    fail_unless(missing_attrs | HBAC_RULE_ELEMENT_TARGETHOSTS,
+    ck_assert_msg(missing_attrs | HBAC_RULE_ELEMENT_TARGETHOSTS,
                 "missing_attrs failed for HBAC_RULE_ELEMENT_TARGETHOSTS");
-    fail_unless(missing_attrs | HBAC_RULE_ELEMENT_SOURCEHOSTS,
+    ck_assert_msg(missing_attrs | HBAC_RULE_ELEMENT_SOURCEHOSTS,
                 "missing_attrs failed for HBAC_RULE_ELEMENT_SOURCEHOSTS");
 
     talloc_free(test_ctx);
